[![PyPI version](https://badge.fury.io/py/rname.svg)](https://badge.fury.io/py/rname)
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Language: Python](https://img.shields.io/badge/Language-Python-blue.svg)](https://shields.io/)
[![Author: Walu](https://img.shields.io/badge/Aurhor-Walu-gray.svg)](https://shields.io/)

# randname

Python module to generate random name.

## Summary

Randname is a python module for generating random name - first and last. 
It uses official data from appropriate governmental/scientific research centers.

Names are drawn with the consideration of their frequency. Therefor most common 
name wil be drawn much more often (this feature can be disabled).

Currently supported countries:
US, PL, ES.

Default database is small, and constrained to 10000 records for each first and 
last names for every country. Default data size: 60 000 records

With the full database downloaded from project 
[github page](https://github.com/ajwalkiewicz/randname/), 
the amount of names is increased to around 700 000 records.

## Documentation

Detailed documentation of module can by found here:
[randname documentation](https://ajwalkiewicz.github.io/randname/)

## Authors & Contributors

**Author**: Adam Walkiewicz

**Contributors**: Be first!

## License

Randname is licensed under the terms of the [MIT license](license.md)
